Invocations is a collection of reusable `Invoke <http://pyinvoke.org>`_
tasks/task modules, including (but not limited to) Python project management
tools such as documentation building and dependency organization.

It has no stand-alone components and is designed to be imported into your
pre-existing Invoke task files.

Invocations is currently in pre-alpha status and is unsupported. Please follow
the Invoke project's communication channels for updates. Thanks!
